@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014 Hewlett-Packard Development Company, L.P.
+ * (C) Copyright 2014-2016 Hewlett Packard Enterprise Development LP
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -57,6 +57,8 @@ public class VerticaMetricRepo extends VerticaRepo implements Repo<MetricEnvelop
 
   public static final int MAX_COLUMN_LENGTH = 255;
 
+  public static final int MAX_VALUE_META_LENGTH = 2048;
+
   private final SimpleDateFormat simpleDateFormat;
 
   private static final String TENANT_ID = "tenantId";
@@ -367,6 +369,12 @@ public class VerticaMetricRepo extends VerticaRepo implements Repo<MetricEnvelop
       try {
 
         valueMetaString = this.objectMapper.writeValueAsString(valueMeta);
+        if (valueMetaString.length() > MAX_VALUE_META_LENGTH) {
+          logger
+              .error("[{}]: Value meta length {} longer than maximum {}, dropping value meta",
+                     id, valueMetaString.length(), MAX_VALUE_META_LENGTH);
+          return "";
+        }
 
       } catch (JsonProcessingException e) {
 
